"""Ferda verification urls."""

from typing import Dict

from asgiref.sync import sync_to_async
from django.conf import settings as django_settings
from django.http import HttpRequest as Request
from django.urls import path, re_path
from ferda.api import PydanticJsonRenderer
from ninja import NinjaAPI
from ninja.security import django_auth

from ferda_verification.views.verification import VerificationIndexView

from .api import router
from .settings import SETTINGS

api = NinjaAPI(
    urls_namespace="ferda_verification:api",
    # Show API docs in debug mode only
    openapi_url=django_settings.DEBUG and "/openapi.json" or "",
    csrf=True,
    auth=sync_to_async(django_auth),
    renderer=PydanticJsonRenderer(),
)
api.add_router("verification", router)


@api.get(
    "/settings/",
    response={200: Dict[str, object]},
    auth=None,
)
async def settings(request: Request):  # type: ignore[no-untyped-def]
    """Get verification settings."""
    return {
        "VERIFICATION_REASONS": SETTINGS.verification_reasons,
    }


app_name = "ferda_verification"

urlpatterns = [
    path("api/", api.urls),
    re_path("", VerificationIndexView.as_view(), name="index"),
]
